.. :changelog:

History
-------

0.1.0 (2015-01-11)
---------------------
Initial version to manage the conda environments on pyspark cluster workers without involving your cluster admins too heavily.


